@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for tuProlog 2.9.0 and later versions
-%  Last updated on July 23, 2018
+%  Last updated on March 19, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
@@ -191,6 +191,9 @@ numbervars(Term, From, Next) :-
 
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+%
+% valid candidates are proprietary built-in predicates with
+% no side-effects when called with ground arguments
 
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
 	fail.
@@ -278,6 +281,8 @@ numbervars(Term, From, Next) :-
 '$lgt_default_flag'(unknown_predicates, warning).
 '$lgt_default_flag'(undefined_predicates, warning).
 '$lgt_default_flag'(singleton_variables, warning).
+'$lgt_default_flag'(steadfastness, silent).
+'$lgt_default_flag'(naming, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
