@@ -1,17 +1,17 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on December 8, 2018
+%  Last updated on March 28, 2019
 %
-%  This file is part of Logtalk <https://logtalk.org/>  
+%  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
 %  You may obtain a copy of the License at
-%  
+%
 %      http://www.apache.org/licenses/LICENSE-2.0
-%  
+%
 %  Unless required by applicable law or agreed to in writing, software
 %  distributed under the License is distributed on an "AS IS" BASIS,
 %  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -93,7 +93,7 @@
 %
 %  predicate properties
 %
-%  this predicate must return at least static, dynamic, and built_in 
+%  this predicate must return at least static, dynamic, and built_in
 %  properties for an existing predicate (and ideally meta_predicate/1
 %  properties for built-in predicates and library predicates)
 %
@@ -220,6 +220,9 @@
 
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
+%
+% valid candidates are proprietary built-in predicates with
+% no side-effects when called with ground arguments
 
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(_) :-
 	fail.
@@ -246,7 +249,7 @@
 %
 %  these extensions are used by Logtalk load/compile predicates
 %
-%  you may want to change the extension for the intermediate files 
+%  you may want to change the extension for the intermediate files
 %  generated by the Logtalk compiler ("object" files) to match the
 %  extension expected by default by your Prolog compiler
 %
@@ -334,6 +337,8 @@
 '$lgt_default_flag'(unknown_predicates, warning).
 '$lgt_default_flag'(undefined_predicates, warning).
 '$lgt_default_flag'(singleton_variables, warning).
+'$lgt_default_flag'(steadfastness, silent).
+'$lgt_default_flag'(naming, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
@@ -844,7 +849,9 @@ user:goal_expansion(phrase(Rule, Input), ExpandedGoal) :-
 	'$lgt_user_module_qualification'('$lgt_phrase'(Rule, Input, ExCtx), ExpandedGoal).
 % optimize messages sent from modules (including "user")
 user:goal_expansion('::'(Object, Message), ExpandedGoal) :-
-	% find out in which module Logtalk was loaded (usually, "user") 
+	callable(Object),
+	callable(Message),
+	% find out in which module Logtalk was loaded (usually, "user")
 	'$lgt_user_module_qualification'(xx, QualifiedGoal),
 	QualifiedGoal = ':'(UserModule, xx),
 	% this module plays the role of the Logtalk pseudo-object "user"
@@ -860,7 +867,7 @@ user:goal_expansion('::'(Object, Message), ExpandedGoal) :-
 		% use default value of the "events" flag
 		'$lgt_current_flag_'(events, Events)
 	),
-	'$lgt_comp_ctx'(Ctx, _, _, user, user, user, Obj, _, [], [], ExCtx, compile(aux), [], Line-Line),
+	'$lgt_comp_ctx'(Ctx, _, _, user, user, user, Obj, _, [], [], ExCtx, compile(aux,_,_), [], Line-Line),
 	'$lgt_execution_context'(ExCtx, user, user, user, Obj, [], []),
 	catch('$lgt_compile_message_to_object'(Message, Object, Goal, Events, Ctx), _, fail),
 	'$lgt_user_module_qualification'(Goal, ExpandedGoal).
