@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths for the developer tools
-%  Last updated on October 24, 2017
+%  Last updated on January 16, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>
-%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
+%  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -35,12 +35,13 @@ logtalk_library_path(tools, logtalk_user('tools/')).
 logtalk_library_path(assertions, tools('assertions/')).
 logtalk_library_path(code_metrics, tools('code_metrics/')).
 logtalk_library_path(dead_code_scanner, tools('dead_code_scanner/')).
+logtalk_library_path(debug_messages, tools('debug_messages/')).
 logtalk_library_path(debugger, tools('debugger/')).
 logtalk_library_path(diagrams, tools('diagrams/')).
 logtalk_library_path(doclet, tools('doclet/')).
 logtalk_library_path(help, tools('help/')).
 logtalk_library_path(lgtdoc, tools('lgtdoc/')).
 logtalk_library_path(lgtunit, tools('lgtunit/')).
-logtalk_library_path(ports, tools('ports/')).
+logtalk_library_path(ports_profiler, tools('ports_profiler/')).
 logtalk_library_path(profiler, tools('profiler/')).
 logtalk_library_path(wrapper, tools('wrapper/')).
